"use strict";
/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.isScribeCheckpointQuorumScrubbed = exports.isGlobalCheckpoint = exports.isLocalCheckpoint = exports.getClientIds = exports.sendToDeli = exports.initializeProtocol = void 0;
const protocol_base_1 = require("@fluidframework/protocol-base");
const server_services_core_1 = require("@fluidframework/server-services-core");
const initializeProtocol = (protocolState) => new protocol_base_1.ProtocolOpHandler(protocolState.minimumSequenceNumber, protocolState.sequenceNumber, protocolState.members, protocolState.proposals, protocolState.values, () => -1);
exports.initializeProtocol = initializeProtocol;
const sendToDeli = async (tenantId, documentId, producer, operation) => {
    if (!producer) {
        throw new Error("Invalid producer");
    }
    const message = {
        clientId: null,
        documentId,
        operation,
        tenantId,
        timestamp: Date.now(),
        type: server_services_core_1.RawOperationType,
    };
    return producer.send([message], tenantId, documentId);
};
exports.sendToDeli = sendToDeli;
const getClientIds = (protocolState, clientCount) => {
    return protocolState.members.slice(0, clientCount).map((member) => member[0]);
};
exports.getClientIds = getClientIds;
/**
 * Whether to write checkpoint to local db.
 * @param noActiveClients - whether there are any active clients
 * @param globalCheckpointOnly - whether to always write checkpoints to global db
 * @returns whether to write checkpoint to local db
 */
const isLocalCheckpoint = (noActiveClients, globalCheckpointOnly) => {
    return !(0, exports.isGlobalCheckpoint)(noActiveClients, globalCheckpointOnly);
};
exports.isLocalCheckpoint = isLocalCheckpoint;
/**
 * Whether to write checkpoint to global db.
 * @param noActiveClients - whether there are any active clients
 * @param globalCheckpointOnly - whether to always write checkpoints to global db
 * @returns whether to write checkpoint to global db
 */
const isGlobalCheckpoint = (noActiveClients, globalCheckpointOnly) => {
    return noActiveClients || globalCheckpointOnly;
};
exports.isGlobalCheckpoint = isGlobalCheckpoint;
/**
 * Whether the quorum members represented in the checkpoint's protocol state have had their user data scrubbed
 * for privacy compliance.
 */
const isScribeCheckpointQuorumScrubbed = (checkpoint) => {
    if (!checkpoint) {
        return false;
    }
    const parsedCheckpoint = typeof checkpoint === "string" ? JSON.parse(checkpoint) : checkpoint;
    for (const [, sequencedClient] of parsedCheckpoint.protocolState.members) {
        const user = sequencedClient.client.user;
        if (!user.id) {
            // User information was scrubbed.
            return true;
        }
    }
    return false;
};
exports.isScribeCheckpointQuorumScrubbed = isScribeCheckpointQuorumScrubbed;
//# sourceMappingURL=utils.js.map